mod components;
mod routes;

use routes::{index, story};

use axum::{routing::get, Router};
use std::net::SocketAddr;
use wattpad::Wattpad;

#[derive(Clone)]
pub struct State {
    pub wattpad: Wattpad,
}

#[tokio::main]
async fn main() {
    tracing_subscriber::fmt::init();

    let state = State {
        wattpad: Wattpad::new().await.unwrap(),
    };
    let addr: SocketAddr = "127.0.0.1:3000".parse().unwrap();
    let app = Router::new()
        .route("/", get(index::render))
        .route("/story", get(story::render))
        .with_state(state);

    tracing::info!("Listening on {}", addr);

    let _ = axum::Server::bind(&addr)
        .serve(app.into_make_service())
        .await;
}
